==> politicsnlp-0.0.10.tar.gz: politicsnlp-0.0.10/politicsnlp/__init__.py <==
# ----------------------------------- Individual --------------------------------------------------- #
from politicsnlp.individual.individual import *
from politicsnlp.individual.strongman import *
from politicsnlp.individual.monarch import *
from politicsnlp.individual.tyrant import *
from politicsnlp.individual.civil_servant import *
# ----------------------------------- People --------------------------------------------------- #
from politicsnlp.people.person import *
from politicsnlp.people.masses import *
from politicsnlp.people.people import *
from politicsnlp.people.crowd import *
from politicsnlp.people.pink_youth import *
from politicsnlp.people.red_generation import *

# ----------------------------------- Core --------------------------------------------------- #
from politicsnlp.core.justice import *
from politicsnlp.core.freedom import *
from politicsnlp.core.democracy import *
from politicsnlp.core.spirit_of_the_law import *
from politicsnlp.core.separation_of_powers import *
from politicsnlp.core.natural_rights import *


from politicsnlp.government import *
from politicsnlp.dictatorship import *
from politicsnlp.philosophy.idealstate import *
from politicsnlp.hegemony import *
from politicsnlp.protection import *
from politicsnlp.revolution import *
from politicsnlp.sanctions import *
from politicsnlp.the_tyranny_of_the_majority import *
from politicsnlp.social_contract import *
from politicsnlp.limited_power import *

# ----------------------------------- Ideology --------------------------------------------------- #
from politicsnlp.ideology.ideology import *
from politicsnlp.ideology.nationalism import *
from politicsnlp.ideology.confucianism import *
# ----------------------------------- Form Of Government --------------------------------------------------- #
from politicsnlp.form_of_government.aristocracy import *
from politicsnlp.form_of_government.autocracy import *
from politicsnlp.form_of_government.form_of_government import *
from politicsnlp.form_of_government.socialism import *
from politicsnlp.form_of_government.colonialism import *
from politicsnlp.form_of_government.communism import *
from politicsnlp.form_of_government.direct_democracy import *
from politicsnlp.form_of_government.representative_democracy import *
from politicsnlp.form_of_government.direct_democracy import *
from politicsnlp.form_of_government.oligarchy import *
from politicsnlp.form_of_government.monarchy import *
from politicsnlp.form_of_government.theocracy import *
# ----------------------------------- Marxism --------------------------------------------------- #
from politicsnlp.marxism.marxism import *
from politicsnlp.marxism.mao_ze_dong_thought import *
from politicsnlp.marxism.deng_xiao_ping_theory import *
from politicsnlp.marxism.xi_jin_ping_thought import *
from politicsnlp.marxism.people_democracy import *
from politicsnlp.peoples_congress_system import *
from politicsnlp.marxism.public_ownership import *
from politicsnlp.marxism.distribution_according_to_work import *
from politicsnlp.marxism.surplus_value import *

==> politicsnlp-0.0.11.tar.gz: politicsnlp-0.0.11/politicsnlp/__init__.py <==
# ----------------------------------- Individual --------------------------------------------------- #
from politicsnlp.individual.individual import *
from politicsnlp.individual.strongman import *
from politicsnlp.individual.monarch import *
from politicsnlp.individual.tyrant import *
from politicsnlp.individual.civil_servant import *
# ----------------------------------- Party --------------------------------------------------- #
from politicsnlp.party.UKIP import *
from politicsnlp.party.conservative_party import *
# ----------------------------------- People --------------------------------------------------- #
from politicsnlp.people.person import *
from politicsnlp.people.masses import *
from politicsnlp.people.people import *
from politicsnlp.people.crowd import *
from politicsnlp.people.pink_youth import *
from politicsnlp.people.red_generation import *

# ----------------------------------- Core --------------------------------------------------- #
from politicsnlp.core.justice import *
from politicsnlp.core.freedom import *
from politicsnlp.core.democracy import *
from politicsnlp.core.spirit_of_the_law import *
from politicsnlp.core.separation_of_powers import *
from politicsnlp.core.natural_rights import *
# ----------------------------------- Diplomacy --------------------------------------------------- #
from politicsnlp.diplomacy.hegemony import *
from politicsnlp.diplomacy.coercive_diplomacy import *


from politicsnlp.government import *
from politicsnlp.dictatorship import *
from politicsnlp.philosophy.idealstate import *
from politicsnlp.protection import *
from politicsnlp.revolution import *
from politicsnlp.sanctions import *
from politicsnlp.the_tyranny_of_the_majority import *
from politicsnlp.social_contract import *
from politicsnlp.limited_power import *
from politicsnlp.territory import *
from politicsnlp.centralization import *
from politicsnlp.political_movement import *
from politicsnlp.political_regime import *
from politicsnlp.leftist import *
from politicsnlp.rightist import *
from politicsnlp.intelligence import *
from politicsnlp.tense_air import *
from politicsnlp.special_military_operations import *
from politicsnlp.purges import *
from politicsnlp.information_literacy import *
from politicsnlp.false_flag_operation import *
from politicsnlp.discourse_power import *
from politicsnlp.orientalism import *
from politicsnlp.de_orientalizing import *
from politicsnlp.eurosceptics import *
from politicsnlp.hawks import *


# ----------------------------------- Ideology --------------------------------------------------- #
from politicsnlp.ideology.ideology import *
from politicsnlp.ideology.nationalism import *
from politicsnlp.ideology.confucianism import *
from politicsnlp.ideology.liberalism import *
from politicsnlp.ideology.populism import *

# ----------------------------------- Form Of Government --------------------------------------------------- #
from politicsnlp.form_of_government.aristocracy import *
from politicsnlp.form_of_government.autocracy import *
from politicsnlp.form_of_government.form_of_government import *
from politicsnlp.form_of_government.socialism import *
from politicsnlp.form_of_government.colonialism import *
from politicsnlp.form_of_government.communism import *
from politicsnlp.form_of_government.direct_democracy import *
from politicsnlp.form_of_government.representative_democracy import *
from politicsnlp.form_of_government.direct_democracy import *
from politicsnlp.form_of_government.oligarchy import *
from politicsnlp.form_of_government.monarchy import *
from politicsnlp.form_of_government.theocracy import *
# ----------------------------------- Marxism --------------------------------------------------- #
from politicsnlp.marxism.marxism import *
from politicsnlp.marxism.mao_ze_dong_thought import *
from politicsnlp.marxism.deng_xiao_ping_theory import *
from politicsnlp.marxism.xi_jin_ping_thought import *
from politicsnlp.marxism.people_democracy import *
from politicsnlp.peoples_congress_system import *
from politicsnlp.marxism.public_ownership import *
from politicsnlp.marxism.distribution_according_to_work import *
from politicsnlp.marxism.surplus_value import *
from politicsnlp.tense_air import TenseAir
